Struct amazon_sp_aplus_content::models::standard_single_image_highlights_module::StandardSingleImageHighlightsModule
source · [−]pub struct StandardSingleImageHighlightsModule {
pub image: Option<Box<ImageComponent>>,
pub headline: Option<Box<TextComponent>>,
pub text_block1: Option<Box<StandardTextBlock>>,
pub text_block2: Option<Box<StandardTextBlock>>,
pub text_block3: Option<Box<StandardTextBlock>>,
pub bulleted_list_block: Option<Box<StandardHeaderTextListBlock>>,
}Expand description
StandardSingleImageHighlightsModule : A standard image with several paragraphs and a bulleted list.
Fields
image: Option<Box<ImageComponent>>headline: Option<Box<TextComponent>>text_block1: Option<Box<StandardTextBlock>>text_block2: Option<Box<StandardTextBlock>>text_block3: Option<Box<StandardTextBlock>>bulleted_list_block: Option<Box<StandardHeaderTextListBlock>>Implementations
sourceimpl StandardSingleImageHighlightsModule
impl StandardSingleImageHighlightsModule
sourcepub fn new() -> StandardSingleImageHighlightsModule
pub fn new() -> StandardSingleImageHighlightsModule
A standard image with several paragraphs and a bulleted list.